import { ref, reactive, watch } from 'vue';

export default function useFetchTable(apiFn, data = {}) {
  let requestData = { ...data };
  let pagination = reactive({
    page: 1,
    pageSize: data.pageSize || 10,
    pageCount: 0,
    showSizePicker: true,
    pageSizes: [10, 20, 50],
    onChange: (page) => {
      pagination.page = page;
    },
    onUpdatePageSize: (pageSize) => {
      pagination.pageSize = pageSize;
      pagination.page = 1;
    },
  });
  const loading = ref(false);
  const tableData = ref([]);
  const fetchData = async (requestParams) => {
    loading.value = true;
    if (requestParams) {
      requestData = Object.assign({}, requestData, requestParams);
    }
    try {
      let params = {
        pageNow: pagination.page,
        pageSize: pagination.pageSize,
        ...requestData,
      };
      let res = await apiFn(params);
      let list = Array.isArray(res.list) ? res.list : [];
      tableData.value = list;
      pagination.pageCount = res.totalPage;
      loading.value = false;
    } catch (err) {}
  };
  fetchData(requestData);
  watch([() => pagination.page, () => pagination.pageSize], () => {
    fetchData(requestData);
  });

  return { loading, pagination, tableData, fetchData };
}
